// +-------------------------------------------+
// |  ___   _     _____   __  __  ____   ____  |
// | | __| | |   | /_\ |  \ \/ / | ___| | /\ | |
// | |__ | | |_  |  _  |   \  /  | __|  | \/ / |
// | |___| |___| |_| |_|   |__|  |____| |_| \\ |
// |  Greek2me              Blockland ID 11902 |
// +-------------------------------------------+

//Create the game mode template.
// new ScriptGroup(Slayer_GameModeTemplateSG)
// {
	// className = "Slayer_TeamElimination";
	// uiName = "Team Elimination";
	// useTeams = true;
// };
new ScriptGroup(Slayer_GameModeTemplateSG)
{
	className = "Slayer_Elimination";
	uiName = "Elimination";
	useTeams = false;
	
	//locked preferences
	locked_lives = 0;
};

function Slayer_Elimination::onGameModeStart(%this)
{
	%this.lowestScoreSS = new SimSet();
}

function Slayer_Elimination::onGameModeEnd(%this)
{
	cancel(%this.elimTimerSched);
	%this.lowestScoreSS.delete();
}

function Slayer_Elimination::onRoundStart(%this)
{
	%this.timerTick(0, %this.minigame.eliminationInitialTime, 0);
}

function Slayer_Elimination::onRoundEnd(%this, %winner, %nameList)
{
	cancel(%this.elimTimerSched);
}

function Slayer_Elimination::onClientDisplayRules(%this, %client)
{
	messageClient(%client, '', "\c5 + Don't have the least points when the checkpoint is reached!");
}

function Slayer_Elimination::timerTick(%this, %tick, %checkpointTick, %round)
{
	%mini = %this.minigame;
	if(%mini.isResetting())
		return;

	if(%tick >= %checkpointTick && %mini.numMembers > 1)
	{
		%this.lowestScoreSS.clear();
		%least = %mini.member[0].score;
		%this.lowestScoreSS.add(%mini.member[0]);
		for(%i = 1; %i < %mini.numMembers; %i ++)
		{
			%client = %mini.member[%i];
			%score = %client.score;
			if(%score < %least)
			{
				%least = %score;
				%this.lowestScoreSS.clear();
				%this.lowestScoreSS.add(%client);
			}
			else if(%score == %least)
			{
				%this.lowestScoreSS.add(%client);
			}
		}
		%count = %this.lowestScoreSS.getCount();
		if(%count > 0 && %count < %mini.numMembers)
		{
			// remove losers from game
			for(%i = 0; %i < %count; %i ++)
			{
				%client = %this.lowestScoreSS.getObject(%i);
				%client.setDead(true);
				if(isObject(%client.player))
					%client.player.delete();
				%client.spectateInit();
				%client.bottomPrint("<just:center><font:Arial Bold:50><color:ff00ff>YOU WERE ELIMINATED", 3, true);
			}

			// Determine if there is a winner.
			%winner = 0;
			%someoneAlive = false;
			for(%i = 0; %i < %mini.numMembers; %i ++)
			{
				%client = %mini.member[%i];
				if(!%client.dead())
				{
					if(%winner)
					{
						%winner = 0;
						break;
					}
					%winner = %client;
					%someoneAlive = true;
				}
			}
			if(%winner)
			{
				%mini.endRound(%winner);
				%this.lowestScoreSS.clear();
				return;
			}
			else if(!%someoneAlive)
			{
				%mini.endRound(0);
				%this.lowestScoreSS.clear();
				return;
			}
		}
		%inc = %mini.eliminationIncrementTime + %round * %mini.eliminationIncrementScale;
		%newCheckpoint = getMax(%checkpointTick + %inc, %mini.eliminationMinTime);
		cancel(%this.elimTimerSched);
		%this.elimTimerSched = %this.scheduleNoQuota(1000, "timerTick", 0, %newCheckpoint, %round + 1);
		%this.lowestScoreSS.clear();
		
		// Announce the new checkpoint.
		for(%i = 0; %i < %mini.numMembers; %i ++)
		{
			%client = %mini.member[%i];
			if(!%client.dead())
			{
				%client.bottomPrint("<just:center><font:Arial Bold:50><color:ff00ff>CHECKPOINT REACHED", 3, true);
			}
		}
	}
	else if(%mini.numMembers < 2)
	{
		// Not enough people, so just wait...
		cancel(%this.elimTimerSched);
		%this.elimTimerSched = %this.scheduleNoQuota(1000, "timerTick", 0, %mini.eliminationInitialTime, 0);
	}
	else
	{
		%remain = %checkpointTick - %tick;
		if(%remain % 10 == 0 && %remain <= 30) //30, 20, 10 seconds remaining
		{
			%announce = 1;
		}
		else if(%remain <= 5) // <= 5 seconds remaining
		{
			%announce = 1;
		}

		if(%announce && %tick > 0)
		{
			%sound = "Slayer_" @ %remain @ "_Seconds_Sound";
			if(isObject(%sound))
				%mini.play2dAll(%sound);
			%mini.bottomPrintAll("<font:Arial Bold:100><color:ff00ff>" @ %remain, 1.5, true);
		}

		cancel(%this.elimTimerSched);
		%this.elimTimerSched = %this.scheduleNoQuota(1000, "timerTick", %tick + 1, %checkpointTick, %round);
	}
}